/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataCloudflareFirewallRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique identifier of the firewall rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.0.0/docs/data-sources/firewall_rule#id DataCloudflareFirewallRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier of the firewall rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.0.0/docs/data-sources/firewall_rule#rule_id DataCloudflareFirewallRule#rule_id}
    */
    readonly ruleId: string;
    /**
    * Identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.0.0/docs/data-sources/firewall_rule#zone_id DataCloudflareFirewallRule#zone_id}
    */
    readonly zoneId: string;
}
export interface DataCloudflareFirewallRuleFilter {
}
export declare function dataCloudflareFirewallRuleFilterToTerraform(struct?: DataCloudflareFirewallRuleFilter): any;
export declare function dataCloudflareFirewallRuleFilterToHclTerraform(struct?: DataCloudflareFirewallRuleFilter): any;
export declare class DataCloudflareFirewallRuleFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareFirewallRuleFilter | undefined;
    set internalValue(value: DataCloudflareFirewallRuleFilter | undefined);
    get deleted(): cdktf.IResolvable;
    get description(): string;
    get expression(): string;
    get id(): string;
    get paused(): cdktf.IResolvable;
    get ref(): string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.0.0/docs/data-sources/firewall_rule cloudflare_firewall_rule}
*/
export declare class DataCloudflareFirewallRule extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "cloudflare_firewall_rule";
    /**
    * Generates CDKTF code for importing a DataCloudflareFirewallRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataCloudflareFirewallRule to import
    * @param importFromId The id of the existing DataCloudflareFirewallRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.0.0/docs/data-sources/firewall_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataCloudflareFirewallRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/5.0.0/docs/data-sources/firewall_rule cloudflare_firewall_rule} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataCloudflareFirewallRuleConfig
    */
    constructor(scope: Construct, id: string, config: DataCloudflareFirewallRuleConfig);
    get action(): string;
    get description(): string;
    private _filter;
    get filter(): DataCloudflareFirewallRuleFilterOutputReference;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get paused(): cdktf.IResolvable;
    get priority(): number;
    get products(): string[];
    get ref(): string;
    private _ruleId?;
    get ruleId(): string;
    set ruleId(value: string);
    get ruleIdInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
